#! /bin/sh


FILE_DIR=../testfiles
DATA_FILE=SVM07_tgd.h5
XML_FILE=D34862-VIIRS-M7.xml
GEO_LOC_FILE=GMODO_tgd.h5
NCDUMP=../ncdump
H5DUMP=h5dump
H5AUGJPSS=../h5augjpss

RETVAL=1

mkdir output

COPY_FILES()
{
  cp $FILE_DIR/$DATA_FILE tmp
  cp $FILE_DIR/$XML_FILE tmp
  cp $FILE_DIR/$GEO_LOC_FILE tmp
}

echo "________________________________________________________________________________"
mkdir tmp
COPY_FILES
echo ""
echo "Try to view original file with $NCDUMP -h $DATA_FILE" 
echo "Expected output:  NetCDF: Bad type ID"
echo ""
$NCDUMP tmp/$DATA_FILE 
RETVAL=$?
if [ "$RETVAL" = "0" ]; then
  echo "test 1 aborted:  original file can be dumped with ncdump."
  exit 1
fi
echo ""
echo "Run test 1:  $H5AUGJPSS tmp/$XML_FILE tmp/$DATA_FILE"
echo ""
$H5AUGJPSS tmp/$XML_FILE tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" != "0" ]; then
  echo "test 1                                                           FAILED."
  exit 1
fi
echo ""
echo "Try $NCDUMP -h $DATA_FILE again, saved to output/final1.out"
$NCDUMP -h tmp/$DATA_FILE >& output/final1.out
RETVAL=$?
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "test 1                                                           FAILED."
  echo ""
  exit 1
else 
  echo ""
  echo "test 1                                                           PASSED."
  echo ""
fi
 
echo "Check for expected number of ATTRIBUTES"
NUMATTS=`$H5DUMP tmp/$DATA_FILE | grep -c ATTRIBUTE`
if [ "${NUMATTS}" = "243" ]; then
  echo ""
  echo "test 1A                                                          PASSED."
  echo ""
else
  echo ""
  echo "test 1A                                                          FAILED."
  echo ""
  exit 1
fi
echo "________________________________________________________________________________"
echo ""

echo "Run restore test 1:  $H5AUGJPSS -r1 tmp/$DATA_FILE"
$H5AUGJPSS -r1 tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" = "0" ]; then
  echo ""
  echo "Try $NCDUMP -h tmp/$DATA_FILE: it should fail with Bad type ID"
  $NCDUMP -h tmp/$DATA_FILE
  RETVAL=$?
fi
if [ "$RETVAL" = "0" ]; then
  echo ""
  echo "Restore test 1                                                   FAILED."
  echo ""
  exit 1
else
  echo ""
  echo "Restore test 1                                                   PASSED."
  echo ""
fi
echo "________________________________________________________________________________"

echo ""
echo "Run restore test 2:  $H5AUGJPSS -r4 tmp/$DATA_FILE"
$H5AUGJPSS -r4 tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" = "0" ]; then
  echo "$H5DUMP -H tmp/$DATA_FILE should now show more than one GROUP"
  GRPS=`$H5DUMP -H tmp/$DATA_FILE | grep -c GROUP`
  echo " Found $GRPS GROUPS"
  if [ "$GRPS" -gt "1" ]; then
    RETVAL=0
  else
    RETVAL=1
  fi
fi
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "Restore test 2                                                   FAILED."
  echo ""
  exit 1
else
  echo ""
  echo "Restore test 2                                                   PASSED."
  echo ""
fi
echo "________________________________________________________________________________"

rm -rf tmp
mkdir tmp
COPY_FILES
echo ""
echo "Try to view original file with $NCDUMP -h $DATA_FILE" 
echo "Expected output:  NetCDF: Bad type ID"
$NCDUMP tmp/$DATA_FILE 
RETVAL=$?
if [ "$RETVAL" = "0" ]; then
  echo "test 2 aborted:  original file can be dumped with ncdump."
  exit 1
fi
echo ""
echo "Run test 2:  $H5AUGJPSS -o1 -o2 -o3 -o4 tmp/$XML_FILE tmp/$DATA_FILE"
echo ""
$H5AUGJPSS -o1 -o2 -o3 -o4 tmp/$XML_FILE tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "test 2                                                           FAILED."
  echo ""
  exit 1
fi
echo ""
echo "Try $NCDUMP -h $DATA_FILE again, saved to output/final2.out"
$NCDUMP -h tmp/$DATA_FILE >& output/final2.out
RETVAL=$?
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "test 2                                                           FAILED."
  echo ""
  exit 1
else 
  echo ""
  echo "test 2                                                           PASSED."
  echo ""
fi
 
echo "Check for expected number of ATTRIBUTES"
NUMATTS=`$H5DUMP tmp/$DATA_FILE | grep -c ATTRIBUTE`
if [ "${NUMATTS}" = "243" ]; then
  echo ""
  echo "test 2A                                                          PASSED."
  echo ""
else
  echo ""
  echo "test 2A                                                          FAILED."
  echo ""
  exit 1
fi

echo ""
echo "Options were applied by default in the first test, and were specified "
echo "explicitly in the second test - the end result should differ only"
echo "by the location of a few attributes."
echo ""
echo "diff output/final1.out output/final2.out"
echo ""
#diff --ignore-matching-lines=".*:DIMENSION_LABELS = \"AlongTrack\", \"CrossTrack\" ;" --ignore-matching-lines="Reflectance:Scaled = 1 ;" --ignore-matching-lines=":HDF5_internal_.*" output/final1.out output/final2.out
diff output/final1.out output/final2.out
if [ $? ]; then
   echo "outputs match                                                   PASSED"
else 
   echo "outputs differ                                                  FAILED"
fi
echo "________________________________________________________________________________"

rm -rf tmp
mkdir tmp
COPY_FILES
echo ""
echo "Try to view new copy of original file with $NCDUMP -h $DATA_FILE" 
echo "Expected output:  NetCDF: Bad type ID"
$NCDUMP tmp/$DATA_FILE 
RETVAL=$?
if [ "$RETVAL" = "0" ]; then
  echo "test 3 aborted:  original file can be dumped with ncdump."
  exit 1
fi
echo ""
echo "Run test 3:  $H5AUGJPSS -o3 tmp/$XML_FILE tmp/$DATA_FILE"
echo "             $H5AUGJPSS -o2 tmp/$XML_FILE tmp/$DATA_FILE"
echo "             $H5AUGJPSS -o4 tmp/$XML_FILE tmp/$DATA_FILE"
echo "             $H5AUGJPSS -o1 tmp/$XML_FILE tmp/$DATA_FILE"
echo ""
$H5AUGJPSS -o3 tmp/$XML_FILE tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "test 3-1                                                         FAILED."
  echo ""
  exit 1
fi
$H5AUGJPSS -o2 tmp/$XML_FILE tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "test 3-2                                                         FAILED."
  echo ""
  exit 1
fi
$H5AUGJPSS -o4 tmp/$XML_FILE tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "test 3-3                                                         FAILED."
  echo ""
  exit 1
fi
$H5AUGJPSS -o1 tmp/$XML_FILE tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "test 3-4                                                         FAILED."
  echo ""
  exit 1
fi
echo ""
echo "Try $NCDUMP -h $DATA_FILE again, saved to output/final3.out"
$NCDUMP -h tmp/$DATA_FILE >& output/final3.out
RETVAL=$?
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "test 3                                                           FAILED."
  echo ""
  exit 1
else
  echo ""
  echo "test 3                                                           PASSED."
  echo ""
fi

echo "Check for expected number of ATTRIBUTES"
NUMATTS=`$H5DUMP tmp/$DATA_FILE | grep -c ATTRIBUTE`
if [ "${NUMATTS}" = "243" ]; then
  echo ""
  echo "test 3A                                                          PASSED."
  echo ""
else
  echo ""
  echo "test 3A                                                          FAILED."
  echo ""
  exit 1
fi

echo ""
echo "Options were applied together in the first test, individually and in a "
echo "different order in the third test - the end result should differ only"
echo "by the location of a few attributes."
echo ""
echo "diff --ignore-matching-lines=\".*:DIMENSION_LABELS = \"AlongTrack\", \"CrossTrack\" ;\" --ignore-matching-lines=\"Reflectance:Scaled = 1 ;\" --ignore-matching-lines=\":HDF5_internal_.*\" output/final1.out output/final2.out"
echo ""
diff --ignore-matching-lines=".*:DIMENSION_LABELS = \"AlongTrack\", \"CrossTrack\" ;" --ignore-matching-lines="Reflectance:Scaled = 1 ;" --ignore-matching-lines=":HDF5_internal_.*" output/final1.out output/final3.out

if [ $? ]; then
   echo "outputs match                                                   PASSED"
else 
   echo "outputs differ                                                  FAILED"
fi
echo "________________________________________________________________________________"

echo ""
echo "Run restore tests, this time together."
echo "Run restore test 2:  $H5AUGJPSS-r4 -r1 tmp/$DATA_FILE"
$H5AUGJPSS -r4 -r1 tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" = "0" ]; then
  echo ""
  echo "$H5DUMP -H tmp/$DATA_FILE should now show more than one GROUP"
  GRPS=`$H5DUMP -H tmp/$DATA_FILE | grep -c GROUP`
  echo " Found $GRPS GROUPS"
  if [ "$GRPS" -gt "1" ]; then
    RETVAL=0
  else
    RETVAL=1
  fi
fi
if [ "$RETVAL" != "0" ]; then
  echo ""
  echo "Restore test 2                                                   FAILED."
  exit 1
else
  echo "Restore test 2                                                   PASSED."
fi

echo "Try $NCDUMP -h tmp/$DATA_FILE: it should fail with Bad type ID"
echo "Expected output:  NetCDF: Bad type ID"
$NCDUMP -h tmp/$DATA_FILE
RETVAL=$?
if [ "$RETVAL" = "0" ]; then
  echo ""
  echo "Restore test 1                                                   FAILED."
  echo ""
  exit 1
else
  echo ""
  echo "Restore test 1                                                   PASSED."
  echo ""
fi
echo "________________________________________________________________________________"

echo ""
echo "Try command without the data file."
$H5AUGJPSS -o1 tmp/$XML_FILE 
RETVAL=$?
if [ "$RETVAL" = "0" ]; then
  echo ""
  echo "Wrong file test 1                                                   FAILED."
  echo ""
  exit 1
else
  echo ""
  echo "Wrong file test 1                                                   PASSED."
  echo ""
fi
rm -rf output tmp

